@@ -14,22 +14,7 @@ getPreValues <- function(cache, col){
   return(list(V=V, X=X, unknown=unknown, known=known, Vkk=Vkk, Vuu=Vuu, Vku=Vku, Vuk=Vuk, iVkk=iVkk, sigmabar=sigmabar, mubarmat=mubarmat, cholSigmabar=cholSigmabar))
 }
 
-# 
-#cMVNorm <- function(cache, pars, prevalues=pv, known=FALSE){
-#  X <- prevalues$X
-#  known <- prevalues$known
-#  unknown <- prevalues$unknown
-#  mu <- rep(pars$pred.root, cache$n)
-#  muk <- mu[known]
-#  muu <- mu[unknown]
-#  mubar <- t(muu + prevalues$mubarmat%*%(X[known]-muk))
-#  #sigmabar <- pars$pred.sig2*prevalues$sigmabar
-#  myChol <-sqrt(pars$pred.sig2)*prevalues$cholSigmabar
-#  res <- dmvn(pars$missing.pred, mu=mubar, sigma = myChol, log=TRUE, isChol=TRUE)
-#  return(res)
-#}
-
-## Proposal function to simulate conditional draws from a multivariate normal distribution
+# Proposal function to simulate conditional draws from a multivariate normal distribution
 .imputePredBM <- function(cache, pars, d, move,ct=NULL, prevalues=pv, prior=prior){
   #(tree, dat, sig2, plot=TRUE, ...){
   X <- prevalues$X
@@ -52,7 +37,7 @@ getPreValues <- function(cache, col){
   return(list(pars=pars.new, hr=hr, decision = type))
 }
 
-.make.monitorFn <- function(model, noMonitor=c("missing.pred", "ntheta"), integers=c("gen","k")){
+.make.monitorFn <- function(model, noMonitor=c("missing.pred", "ntheta"), integers=c("gen","k"), verbose=TRUE){
   parorder <- model$parorder
   rjpars <- model$rjpars
   exclude <- which(parorder %in% noMonitor)
@@ -71,12 +56,14 @@ getPreValues <- function(cache, col){
     names <- pars2monitor
     #names <- c("gen", "lnL", "prior", "alpha" , "sig2", "rbeta1", "endo", "k")
     #string <- "%-8i%-8.2f%-8.2f%-8.2f%-8.2f%-8.2f%-8.2f%-8i"
-    acceptratios <- tapply(accept, accept.type, mean)
+    acceptratios <- unlist(accept/accept.type) #tapply(accept, accept.type, mean)
     names <- c(names, names(acceptratios))
-    if(j==0){
-      cat(sprintf("%-7.7s", names), "\n", sep=" ")                           
+    if (verbose){
+      if(j==0){
+        cat(sprintf("%-7.7s", names), "\n", sep=" ")
+      }
+      cat(sprintf(string, i, lik, pr, pars$alpha, pars$sig2, pars$beta1[1], pars$endo, pars$k), sprintf("%-8.2f", acceptratios),"\n", sep="")
     }
-    cat(sprintf(string, i, lik, pr, pars$alpha, pars$sig2, pars$beta1[1], pars$endo, pars$k), sprintf("%-8.2f", acceptratios),"\n", sep="")
   }
 }
 
@@ -113,105 +100,10 @@ getPreValues <- function(cache, col){
   text(x+adjx, y=seq(y, y+height, length.out=length(ticks)), labels=ticklab, pos=pos,cex=cex.lab, col=text.col)
 }
 
-#' A function to plot a heatmap of reconstructed parameter values on the branches of the tree
-#' 
-#' @param tree A phylogenetic tree
-#' @param chain A bayou MCMC chain
-#' @param variable The parameter to reconstruct across the tree
-#' @param burnin The initial proportion of burnin samples to discard 
-#' @param nn The number of discrete categories to divide the variable into
-#' @param pal A color palette function that produces nn colors
-#' @param legend_ticks The sequence of values to display a legend for
-#' @param legend_settings A list of legend attributes (passed to bayou:::.addColorBar)
-#' @param ... Additional options passed to plot.phylo
-#' 
-#' @details legend_settings is an optional list of any of the following:
-#' 
-#' legend - a logical indicating whether a legend should be plotted
-#' 
-#' x - the x location of the legend
-#' 
-#' y - the y location of the legend
-#' 
-#' height - the height of the legend
-#' 
-#' width - the width of the legend
-#' 
-#' n - the number of gradations in color to plot from the palette
-#' 
-#' adjx - an x adjustment for placing text next to the legend bar
-#' 
-#' cex.lab - the size of text labels next to the legend bar
-#' 
-#' text.col - The color of text labels
-#' 
-#' locator - if TRUE, then x and y coordinates are ignored and legend is placed
-#' interactively.
-#' 
-#' @export
-plotBranchHeatMap <- function(tree, chain, variable, burnin=0, nn=NULL, pal=heat.colors, legend_ticks=NULL, legend_settings=list(plot=TRUE), ...){
-  dum <- setNames(rep(1, length(tree$tip.label)), tree$tip.label)
-  cache <- .prepare.ou.univariate(tree, dum)
-  tree <- cache$phy
-  seq1 <- floor(max(seq(burnin*length(chain$gen),1), length(chain$gen), 1))
-  if(is.null(legend_ticks)){
-    legend_ticks <- seq(min(unlist(chain[[variable]][seq1],F,F)), max(unlist(chain[[variable]][seq1],F,F)), length.out=5)
-  }
-  if(is.null(nn)) nn <- length(seq1) else { seq1 <- floor(seq(max(burnin*length(chain$gen),1), length(chain$gen), length.out=nn))}
-  if(length(nn) > length(chain$gen)) stop("Number of samples greater than chain length, lower nn")
-  abranches <- lapply(1:nrow(tree$edge), .ancestorBranches, cache=cache)
-  allbranches <- suppressWarnings(sapply(1:nrow(tree$edge), function(x) .branchRegime(x, abranches, chain, variable, seq1, summary=TRUE)))
-  plot(tree, edge.color=.colorRamp(allbranches, pal, 100), ...)
-  lastPP<-get("last_plot.phylo",envir=.PlotPhyloEnv)
-  legend_stuff <- list(x=0.01* lastPP$x.lim[2], 
-                       y=0, 
-                       height=0.25*diff(lastPP$y.lim), 
-                       width=0.01*diff(lastPP$x.lim), 
-                       n=100, 
-                       trait=allbranches, 
-                       ticks=legend_ticks, 
-                       adjx=0.01*lastPP$x.lim[2], 
-                       cex.lab=0.5, 
-                       text.col="black",
-                       plot=TRUE,
-                       locator=FALSE
-                       )
-  if(length(legend_settings) > 0){
-    for(i in 1:length(legend_settings)){
-      legend_stuff[[names(legend_settings)[i]]] <- legend_settings[[i]]
-    }
-  }
-  if(legend_stuff$plot) {
-    if(legend_stuff$locator){
-      lc <- locator(1)
-      legend_stuff$x <- lc$x
-      legend_stuff$y <- lc$y
-      .addColorBar(x=legend_stuff$x, y=legend_stuff$y, height=legend_stuff$height, width=legend_stuff$width, pal=pal, n=legend_stuff$n, trait=allbranches, ticks=legend_ticks, adjx=legend_stuff$adjx, cex.lab=legend_stuff$cex.lab, text.col=legend_stuff$text.col)
-    } else .addColorBar(x=legend_stuff$x, y=legend_stuff$y, height=legend_stuff$height, width=legend_stuff$width, pal=pal, n=legend_stuff$n, trait=allbranches, ticks=legend_ticks, adjx=legend_stuff$adjx, cex.lab=legend_stuff$cex.lab, text.col=legend_stuff$text.col)
-  }
-}
-
-
-.ancestorBranches <- function(branch, cache){
-  ancbranches <- which(sapply(cache$bdesc, function(x) branch %in% x))
-  sort(ancbranches, decreasing=FALSE)
-}
-.branchRegime <- function(branch, abranches, chain, parameter, seqx, summary=FALSE){
-  ancs <- c(branch, abranches[[branch]])
-  ancshifts <- lapply(1:length(seqx), function(x) chain$t2[[seqx[x]]][which(chain$sb[[seqx[x]]] == ancs[min(which(ancs %in% chain$sb[[seqx[x]]]))])])
-  ancshifts <- sapply(ancshifts, function(x) ifelse(length(x)==0, 1, x))
-  ests <- sapply(1:length(ancshifts), function(x) chain[[parameter]][[seqx[x]]][ancshifts[x]])
-  res <- cbind(ests)
-  if(summary){
-    return(apply(res, 2, stats::median))
-  } else {
-    return(res)
-  }
-}
 
 #' This function makes a bayou model object that can be used for customized allometric regression models.
-#' 
-#' @param f A formula describing the relationship between the data and one or more predictors (use 'dat' 
+#'
+#' @param f A formula describing the relationship between the data and one or more predictors (use 'dat'
 #' for the dependent variable)
 #' @param rjpars A character vector of parameters to split at the mapped shifts on the tree
 #' @param tree A phylogenetic tree
@@ -230,17 +122,22 @@ plotBranchHeatMap <- function(tree, chain, variable, burnin=0, nn=NULL, pal=heat
 #' @param shiftpars The names of the parameters defining the map of shifts (for now, always c("sb", "loc", "t2")).
 #' @param model The parameterization of the OU model, either "OU", "OUrepar" or "QG".
 #' @param slopechange "immediate", "alphaWeighted" or "fullPGLS"
-#' 
+#'
 #' @details This function generates a list with the '$model', which provides the specifications of the regression
 #' model and '$startpar', which provides starting values to input into bayou.makeMCMC. Note that this model assumes
 #' that predictors immediately affect trait values at a shift. In other words, regardless of the past history of the
 #' predictor, only the current value affects the current expected trait value. This is only reasonable for allometric
-#' models, although it may be appropriate for other models if phylogenetic inertia is very low (short half-lives). 
-#' 
+#' models, although it may be appropriate for other models if phylogenetic inertia is very low (short half-lives).
+#'
 #' One predictor variable may include missing data (coded as "NA"). The model will assume the maximum-likelihood
 #' best-fit BM model and simulate the missing predictor values throughout the course of the MCMC. These values will
-#' then be used to calculate the likelihood given the parameters for each MCMC step. 
-#' 
+#' then be used to calculate the likelihood given the parameters for each MCMC step.
+#' @return
+#' A list with two elements:
+#' \describe{
+#'   \item{model}{A list containing MCMC settings, likelihood functions, monitoring functions, and other parameters for the Bayesian OU model.}
+#'   \item{startpar}{A list of starting parameter values for the model. If missing data is imputed, it includes `missing.pred`.}
+#' }
 #' @export
 makeBayouModel <- function(f, rjpars, tree, dat, pred, prior, SE=0, slopechange="immediate", impute=NULL, startpar=NULL, moves=NULL, control.weights=NULL, D=NULL, shiftpars=c("sb", "loc", "t2"), model="OU"){
   cache <- .prepare.ou.univariate(tree, dat, SE=SE, pred=pred)
@@ -270,7 +167,7 @@ makeBayouModel <- function(f, rjpars, tree, dat, pred, prior, SE=0, slopechange=
       }
     } else {
       expFn <- function(pars, cache){
-        betaID <- .getTipMap(pars, cache)    
+        betaID <- .getTipMap(pars, cache)
         if(length(impute)>0){
           MF[is.na(MF[,impute]),impute] <- pars$missing.pred #$impute
           MM <- model.matrix(f, MF)
@@ -298,7 +195,7 @@ makeBayouModel <- function(f, rjpars, tree, dat, pred, prior, SE=0, slopechange=
   varnames <- switch(model, "OU"=c("alpha","sig2"), "OUrepar"=c("halflife", "Vy"), "QG"=c("h2", "P", "Ne", "w2"))
   if(model=="OU"){
     varTransform <- function(pars) return(pars)
-  } 
+  }
   if(model=="OUrepar"){
     varTransform <- function(pars){
       repar <- OU.repar(pars)
@@ -340,26 +237,28 @@ makeBayouModel <- function(f, rjpars, tree, dat, pred, prior, SE=0, slopechange=
     llh <- -0.5*(n*log(2*pi)+detV+inv.yVy)
     return(list(loglik=llh, theta=pars$theta,resid=X.c, comp=comp, transf.phy=transf.phy))
   }
-  monitorFn <- function(i, lik, pr, pars, accept, accept.type, j){
+  monitorFn <- function(i, lik, pr, pars, accept, accept.type, j, verbose=TRUE){
     names <- c("gen", "lnL", "prior", varnames, parnames, "rtheta", "k")
     format <- c("%-8i",rep("%-8.2f",4), rep("%-8.2f", length(parnames)), "%-8.2f","%-8i")
-    acceptratios <- tapply(accept, accept.type, mean)
+    acceptratios <- unlist(accept/accept.type) #tapply(accept, accept.type, mean)
     names <- c(names, names(acceptratios))
-    if(j==0){
-      cat(sprintf("%-7.7s", names), "\n", sep=" ")                           
+    if (verbose) {
+      if(j==0){
+        cat(sprintf("%-7.7s", names), "\n", sep=" ")
+      }
+      item <- c(i, lik, pr, pars[[varnames[1]]], pars[[varnames[2]]], sapply(pars[parnames], function(x) x[1]), pars$theta[1], pars$k)
+      cat(sapply(1:length(item), function(x) sprintf(format[x], item[x])), sprintf("%-8.2f", acceptratios),"\n", sep="")
     }
-    item <- c(i, lik, pr, pars[[varnames[1]]], pars[[varnames[2]]], sapply(pars[parnames], function(x) x[1]), pars$theta[1], pars$k)
-    cat(sapply(1:length(item), function(x) sprintf(format[x], item[x])), sprintf("%-8.2f", acceptratios),"\n", sep="")
   }
   rdists <- .getSimDists(prior)
-  ## Set default moves if not specified. 
+  ## Set default moves if not specified.
   if(length(rjpars) > 0){
     if(is.null(moves)){
-      moves =  c(switch(model, "OU" = list(alpha=".multiplierProposal", sig2=".multiplierProposal"), 
-                        "OUrepar" = list(halflife=".jointHalflifeVyProposal", Vy=".jointHalflifeVyProposal")), 
+      moves =  c(switch(model, "OU" = list(alpha=".multiplierProposal", sig2=".multiplierProposal"),
+                        "OUrepar" = list(halflife=".jointHalflifeVyProposal", Vy=".jointHalflifeVyProposal")),
                  as.list(setNames(rep(".vectorSlidingWindowSplit", length(parnames)), parnames)),
                  c(theta=".vectorSlidingWindowSplit", k=".splitmergePrior", slide=".slide2"))
-    } 
+    }
     if(is.null(control.weights)){
       control.weights <- setNames(rep(1, length(parnames)+5), c(varnames, parnames, "k", "theta", "slide"))
       control.weights[c(varnames[1], parnames)] <- 2
@@ -367,7 +266,7 @@ makeBayouModel <- function(f, rjpars, tree, dat, pred, prior, SE=0, slopechange=
       control.weights["k"] <- 5
       control.weights <- as.list(control.weights)
     }
-    
+
     if(is.null(D)){
       D <- lapply(rdists[!(names(rdists) %in% shiftpars)], function(x) sd(x(1000))/50)
       D$k <- rep(1, length(rjpars))
@@ -383,7 +282,7 @@ makeBayouModel <- function(f, rjpars, tree, dat, pred, prior, SE=0, slopechange=
       parorder <- c(parorder, fixed)
     }
     parorder <- parorder[!duplicated(parorder) & !(parorder %in% shiftpars)]
-    
+
     }
     if(is.null(startpar)){
       startpar <- priorSim(prior, cache$phy, shiftpars=rjpars2)$pars[[1]]
@@ -404,8 +303,8 @@ makeBayouModel <- function(f, rjpars, tree, dat, pred, prior, SE=0, slopechange=
   } else {
     rj <- numeric(0)
     if(is.null(moves)){
-      moves =  c(switch(model, "OU" = list(alpha=".multiplierProposal", sig2=".multiplierProposal"), 
-                        "OUrepar" = list(halflife=".jointHalflifeVyProposal", Vy=".jointHalflifeVyProposal")), 
+      moves =  c(switch(model, "OU" = list(alpha=".multiplierProposal", sig2=".multiplierProposal"),
+                        "OUrepar" = list(halflife=".jointHalflifeVyProposal", Vy=".jointHalflifeVyProposal")),
                  as.list(setNames(rep(".vectorSlidingWindowSplit", length(parnames)), parnames)),
                  c(theta=".vectorSlidingWindowSplit"))
     }
@@ -439,16 +338,16 @@ makeBayouModel <- function(f, rjpars, tree, dat, pred, prior, SE=0, slopechange=
       #if(length(attributes(prior)$fixed)>0){
       #  simdists[names(attributes(prior)$fixed)] <- lapply(1:length(attributes(prior)$fixed), function(x) function(n) attributes(prior)$fixed[[x]])
       #  fixed.pars <- attributes(prior)$fixed
-      #} 
+      #}
       #simdists <- simdists[!is.na(names(simdists))]
       #startpar <- lapply(simdists, function(x) x(1))
       #if(!("k" %in% fixed)){
       #  startpar$k <- 0
       #  startpar$ntheta <- startpar$k+1
-      #  if(startpar$k==0) startpar$t2 <- numeric(0) else startpar$t2 <- 2:(startpar$ntheta) 
+      #  if(startpar$k==0) startpar$t2 <- numeric(0) else startpar$t2 <- 2:(startpar$ntheta)
       #} else {
       #  startpar$ntheta <- startpar$k+1
-      #  if(startpar$k==0) startpar$t2 <- numeric(0) else startpar$t2 <- 2:(startpar$ntheta) 
+      #  if(startpar$k==0) startpar$t2 <- numeric(0) else startpar$t2 <- 2:(startpar$ntheta)
       #}
       #startpar <- startpar[c(parorder, shiftpars)]
     }
@@ -461,13 +360,13 @@ makeBayouModel <- function(f, rjpars, tree, dat, pred, prior, SE=0, slopechange=
     model$moves$missing.pred <- ".imputePredBM"
     model$control.weights$missing.pred <- 1
     model$D$missing.pred <- 1
-    startpar <- .imputePredBM(cache, startpar, d=1, NULL, ct=NULL, prevalues=pv)$pars#$impute 
+    startpar <- .imputePredBM(cache, startpar, d=1, NULL, ct=NULL, prevalues=pv)$pars#$impute
     bp <- which(names(startpar)=="pred.root")
     model$parorder <- c(parorder[1:bp], "missing.pred", if(length(parorder)>bp)parorder[(bp+1):length(parorder)] else NULL)
     startpar <- startpar[c(parorder, names(startpar)[!names(startpar) %in% parorder])]
     model$prevalues <- pv
   }
-  
+
   #try(prior(startpar))
   #try(likFn(startpar, cache, cache$dat))
   return(list(model=model, startpar=startpar))
@@ -486,4 +385,4 @@ makeBayouModel <- function(f, rjpars, tree, dat, pred, prior, SE=0, slopechange=
   rdists.fx <- lapply(1:length(rdists.fx),function(x) .set.defaults(rdists.fx[[x]],defaults=prior.params[[x]]))
   names(rdists.fx) <- gsub('^[a-zA-Z]',"",names(rdists))
   return(rdists.fx)
-}
\ No newline at end of file
+}
