@@ -1,22 +1,27 @@
 #' Calculate the weight matrix of a set of regimes on a phylogeny
-#' 
+#'
 #' These functions calculate weight matrices from regimes specified in phytools' simmap format.
-#' \code{simmap.W} calculates the weight matrix for a set of regimes from a phylogeny
-#' with a stored regime history. \code{.simmap.W} calculates the same matrix, but without checks and is 
-#' generally run internally. 
-#' 
-#' @rdname simmap.W
-#' @param tree either a tree of class "phylo" or a cache object produced by bayOU's internal 
+#' \code{simmapW} calculates the weight matrix for a set of regimes from a phylogeny
+#' with a stored regime history. \code{.simmap.W} calculates the same matrix, but without checks and is
+#' generally run internally.
+#'
+#' @rdname simmapW
+#' @param tree either a tree of class "phylo" or a cache object produced by bayOU's internal
 #' functions. Must include list element 'maps' which is a simmap reconstruction of regime history.
 #' @param pars a list of the parameters used to calculate the weight matrix. Only pars$alpha is
 #' necessary to calculate the matrix, but others can be present.
-#' 
+#'
 #' @details \code{.simmap.W} is more computationally efficient within a mcmc and is used internally. The value
 #' of \code{TotExp} is supplied to speed computation and reduce redundancy, and cache objects must be supplied as
 #' the phylogeny, and the parameter \code{ntheta} must be present in the list \code{pars}.
+#'
+#' @return A matrix where each row corresponds to a branch in the phylogenetic tree, and each column
+#' represents an evolutionary regime. The entries in the matrix indicate the weight of a given regime
+#' on a given branch.
+#'
 #' @export
-simmap.W <- function(tree,pars){
-  if(class(tree)=="phylo"){
+simmapW <- function(tree,pars){
+  if(inherits(tree, "phylo")){
     X <- rep(NA,length(tree$tip.label))
     names(X) <- tree$tip.label
     cache <- .prepare.ou.univariate(tree,X)
@@ -89,6 +94,8 @@ simmap.W <- function(tree,pars){
   return(W)
 }
 
+
+
 .parmap.W <- function(cache, pars){
   if(pars$k > 0){
     nbranch <- length(cache$edge.length)
@@ -165,22 +172,26 @@ simmap.W <- function(tree,pars){
 }
 
 #' Calculate the weight matrix of a set of regimes on a phylogeny
-#' 
+#'
 #' These functions calculate weight matrices from regimes specified by a bayou formatted parameter list
 #' \code{parmap.W} calculates the weight matrix for a set of regimes from a phylogeny
-#' with a stored regime history. \code{.parmap.W} calculates the same matrix, but without checks and is 
-#' generally run internally. 
-#' 
+#' with a stored regime history. \code{.parmap.W} calculates the same matrix, but without checks and is
+#' generally run internally.
+#'
 #' @rdname parmap.W
-#' @param tree either a tree of class "phylo" or a cache object produced by bayOU's internal 
+#' @param tree either a tree of class "phylo" or a cache object produced by bayOU's internal
 #' functions. Must include list element 'maps' which is a simmap reconstruction of regime history.
 #' @param pars a list of the parameters used to calculate the weight matrix. Only pars$alpha is
 #' necessary to calculate the matrix, but others can be present.
-#' 
-#' @details \code{.parmap.W} is more computationally efficient within a mcmc and is used internally. 
+#'
+#' @return A matrix where rows correspond to branches in the phylogenetic tree, and columns correspond
+#' to the different evolutionary regimes. Each entry in the matrix represents the weight of a given
+#' regime on a given branch.
+#'
+#' @details \code{.parmap.W} is more computationally efficient within a mcmc and is used internally.
 #' @export
 parmap.W <- function(tree, pars){
-  if(class(tree)=="phylo"){
+  if(inherits(tree, "phylo")){
     X <- rep(NA,length(tree$tip.label))
     names(X) <- tree$tip.label
     cache <- .prepare.ou.univariate(tree,X)
@@ -262,9 +273,9 @@ parmap.W <- function(tree, pars){
   return(W)
 }
 
-#' Calculate the weight matrix for an auteur bm-jumps model
-#'  
-#'  Example: 
+# Calculate the weight matrix for an auteur bm-jumps model
+#
+#  Example:
 #pars <- list(sig2 = 1, sig2jump = 2, k=2, ntheta=3, sb= c(447, 436), t2= c(2, 3), loc= c(0,0))
 .auteur.W <- function(cache, pars){
   nbranch <- length(cache$edge.length)
@@ -300,12 +311,12 @@ parmap.W <- function(tree, pars){
   sb.desc2 <- unlist(sb.desc, F, F)
   sb.dup <- duplicated(sb.desc2)
   sb.desc3 <- sb.desc2[!sb.dup]
-  t2.names <- rep(t2.down[desc.length > 0], unlist(lapply(sb.desc, 
+  t2.names <- rep(t2.down[desc.length > 0], unlist(lapply(sb.desc,
                                                           length), F, F))
   t2.names <- t2.names[!sb.dup]
   t2b[as.character(unlist(sb.desc3, F, F))] <- t2.names
   return(t2b)
 }
-#.auteur.W(cache, pars) %*% 
+#.auteur.W(cache, pars) %*%
 
 
